@@ -1,7 +1,13 @@
 from .clubelo import ClubElo  # noqa
-from .espn import ESPN  # noqa
 from .fbref import FBRef  # noqa
 from .footballdata import FootballData  # noqa
-from .sofifa import SoFifa  # noqa
 from .team_mappings import get_example_team_name_mappings  # noqa
 from .understat import Understat  # noqa
+
+__all__ = [
+    "ClubElo",
+    "FBRef",
+    "FootballData",
+    "get_example_team_name_mappings",
+    "Understat",
+]
